/***************************************************************************
 *   Copyright (C) 2006 by Vincenzo Forchi`,,,   *
 *   tus@ken   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include "diodebpm.h"
#include <qtango.h>
#include <QTimer>
#include <QMessageBox>
#include <elettracolors.h>
#include <history.h>

#include <QtDebug>

DiodeBPM::DiodeBPM(QWidget *parent) : QWidget(parent)
{
	ui.setupUi(this);
	ui.tInterlockEnabled->setBooleanDisplay("DISABLED", "ENABLED", EColor(Elettra::green), EColor(Elettra::darkYellow));
	ui.tInterlockActive->setBooleanDisplay("NORMAL", "ALARM", EColor(Elettra::green), EColor(Elettra::red));

	device = QApplication::arguments()[1];
	connect(ui.pushHistory, SIGNAL(clicked()), this, SLOT(showHistory()));

	QTimer *timer = new QTimer(this);
	timer->setInterval(1000);
	connect(timer, SIGNAL(timeout()), this, SLOT(changeLabel()));
	timer->start();

	QTimer::singleShot(100, this, SLOT(connectToTango()));
}

DiodeBPM::~DiodeBPM()
{
}    

void DiodeBPM::connectToTango()
{
	ui.tA1->setSource(device + "/A1");
	ui.tB1->setSource(device + "/B1");
	ui.tC1->setSource(device + "/C1");
	ui.tD1->setSource(device + "/D1");
	ui.tHor1->setSource(device + "/Hor1");
	ui.tVer1->setSource(device + "/Ver1");

	ui.tA2->setSource(device + "/A2");
	ui.tB2->setSource(device + "/B2");
	ui.tC2->setSource(device + "/C2");
	ui.tD2->setSource(device + "/D2");
	ui.tHor2->setSource(device + "/Hor2");
	ui.tVer2->setSource(device + "/Ver2");

	ui.tInterlockEnabled->setSource(device + "/InterlockEnabled");
	ui.tInterlockActive->setSource(device + "/InterlockActive");

	ui.tGaugeHorInterlockRisk->setSource(device + "/HorInterlockRisk");
	ui.tGaugeVerInterlockRisk->setSource(device + "/VerInterlockRisk");

	setWindowTitle(device.split('/').last());
}

void DiodeBPM::showHistory()
{
	History *win = new History(device, this);
	win->readData();
	win->show();
}

QString DiodeBPM::getLabelValueAsText(QLabel *label)
{
	if(label == NULL)
		return "";
	if (label->text().indexOf('[') == -1)
		return label->text();
	else
		return label->text().split('[')[0];
}

void DiodeBPM::changeLabel()
{
	QString value = getLabelValueAsText(ui.tInterlockEnabled);
	if (value == "Disabled")
		ui.pushHistory->setText("View Post\nMortem");
	else
		ui.pushHistory->setText("View History");
}
