/***************************************************************************
 *   Copyright (C) 2006 by Vincenzo Forchi`,,,   *
 *   tus@ken   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include "history.h"
#include <qtango.h>
#include <device_factory.h>
#include <QTimer>
#include <QFileDialog>
#include <QDateTime>
#include <QMessageBox>
#include <elettracolors.h>

#include <QtDebug>

History::History(QString d, QWidget *parent) : QWidget(parent), device(d)
{
    ui.setupUi(this);
    setWindowTitle(device.split('/').last());
    setWindowFlags(Qt::Window);
    setAttribute(Qt::WA_DeleteOnClose);
    setAttribute(Qt::WA_QuitOnClose, false);
    setMinimumSize(400,300);
    connect(ui.pushSave, SIGNAL(clicked()), this, SLOT(saveData()));
}

void History::readData()
{
    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
    try {
        DeviceProxy *dev = DeviceFactory::instance()->getDeviceProxy(device);
        if(dev) {
            dev->set_timeout_millis(10000);

            vector<string> attrs;
            attrs.push_back("Hor1History");
            attrs.push_back("Hor2History");
            attrs.push_back("Ver1History");
            attrs.push_back("Ver2History");

            vector<DeviceAttribute> *historys = dev->read_attributes(attrs);

            (*historys)[0] >> Hor1History;
            (*historys)[1] >> Hor2History;
            (*historys)[2] >> Ver1History;
            (*historys)[3] >> Ver2History;

            QVector<double> xv;
            for(unsigned int i = 0; i < Hor1History.size(); i++)
                xv << 1;

            ui.plotH1->setAxisTitle(QwtPlot::yLeft, "[mm]");
            ui.plotH1->setTitle("Hor1");
            ui.plotH1->setData("Hor1", xv, QVector<double>::fromStdVector(Hor1History));

            xv.clear();
            for(unsigned int i = 0; i < Ver1History.size(); i++)
                xv << 1;
            ui.plotV1->setAxisTitle(QwtPlot::yLeft, "[mm]");
            ui.plotV1->setTitle("Ver1");
            ui.plotH1->setData("Ver1", xv, QVector<double>::fromStdVector(Ver1History));

            xv.clear();
            for(unsigned int i = 0; i < Hor2History.size(); i++)
                xv << 1;
            ui.plotH2->setAxisTitle(QwtPlot::yLeft, "[mm]");
            ui.plotH2->setTitle("Hor2");
            ui.plotH1->setData("Hor2", xv, QVector<double>::fromStdVector(Hor2History));

            xv.clear();
            for(unsigned int i = 0; i < Ver2History.size(); i++)
                xv << 1;
            ui.plotV2->setAxisTitle(QwtPlot::yLeft, "[mm]");
            ui.plotV2->setTitle("Ver2");
            ui.plotH1->setData("Ver2", xv, QVector<double>::fromStdVector(Hor2History));
        }

    } catch (DevFailed &e) {
        TLog log(e);
        TUtil::instance()->addLog(log);
        QMessageBox::critical(0, "Error", log.formatMessage());
    }
    QApplication::restoreOverrideCursor();
}

void History::saveData()
{
    unsigned int size, i;
    QDateTime d;
    QString s = QFileDialog::getSaveFileName(this, "Choose a filename to save under", QDir::homePath(), "Text file (*.txt)");
    if (!s.isEmpty())
    {
        QFile f(s);
        if (!f.open(QIODevice::WriteOnly | QIODevice::Text))
        {
            QMessageBox::warning(this, "Error", "Can't create file", QMessageBox::Ok, 0, 0);
            return;
        }
        QTextStream out(&f);
        out << fixed;
        out.setRealNumberPrecision(4);
        out << QDateTime::currentDateTime().toString() << '\n';
        out << "H1\tV1\tH2\tV2\n";
        size = Hor1History.size();
        for (i = 0; i < size; i++)
        {
            out << Hor1History[i] << '\t';
            out << Ver1History[i] << '\t';
            out << Hor2History[i] << '\t';
            out << Ver2History[i] << '\n';
        }
        f.close();
    }
}
